@@ -2,7 +2,7 @@
 use cosmwasm_std::testing::{mock_dependencies, mock_env, mock_info};
 use cosmwasm_std::{from_binary, to_binary, CosmosMsg, DepsMut, Empty, Response, WasmMsg};
 
-use cw721::{
+use cw721_terra::{
     ApprovedForAllResponse, ContractInfoResponse, Cw721Query, Cw721ReceiveMsg, Expiration,
     NftInfoResponse, OwnerOfResponse,
 };
@@ -482,7 +482,7 @@ fn approving_all_revoking_all() {
     assert_eq!(
         res,
         ApprovedForAllResponse {
-            operators: vec![cw721::Approval {
+            operators: vec![cw721_terra::Approval {
                 spender: String::from("operator"),
                 expires: Expiration::Never {}
             }]
@@ -514,7 +514,7 @@ fn approving_all_revoking_all() {
     assert_eq!(
         res,
         ApprovedForAllResponse {
-            operators: vec![cw721::Approval {
+            operators: vec![cw721_terra::Approval {
                 spender: String::from("buddy"),
                 expires: buddy_expires,
             }]
@@ -533,7 +533,7 @@ fn approving_all_revoking_all() {
     assert_eq!(
         res,
         ApprovedForAllResponse {
-            operators: vec![cw721::Approval {
+            operators: vec![cw721_terra::Approval {
                 spender: String::from("operator"),
                 expires: Expiration::Never {}
             }]
@@ -561,7 +561,7 @@ fn approving_all_revoking_all() {
     assert_eq!(
         res,
         ApprovedForAllResponse {
-            operators: vec![cw721::Approval {
+            operators: vec![cw721_terra::Approval {
                 spender: String::from("buddy"),
                 expires: buddy_expires,
             }]
